package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`"``!````,!<``#0```"`I@``!Q``<#0`(``+
M`"@`'P`>``8````T````-````#0```!@`0``8`$```0````$`````P```)0!
M``"4`0``E`$```T````-````!`````$````#``!PJ`$``*@!``"H`0``&```
M`!@````$````"````````'#``0``P`$``,`!```8````&`````0````$````
M`0```````````````````#2<```TG```!0```````0`!````-)P``#2<`0`T
MG`$`F`4``+P5```&```````!``(````<`@``'`(``!P"```X`0``.`$```0`
M```$````!````-@!``#8`0``V`$``$0```!$````!`````0```!1Y71D````
M```````````````````````'````$````%+E=&0TG```-)P!`#2<`0#,`P``
MS`,```0````!``````````````````````````````````````````0````O
M;&EB+VQD+G-O+C$`````````````(`(!`0`%`````````````````````/8!
M`+(`````````````````````,"`"``0````4`````P```$=.50#MT@Y<-DF.
MF']:1QG'AK%!6G7A+P0````0`````0```$=.50```````P````(`````````
M`0```#\#```!````3P,```$```!?`P```0```&D#```,````[!,```T```!`
M7```&0```#2<`0`;````!````!H````XG`$`'`````0````$````5`,```4`
M```H#0``!@```(@&```*````!P4```L````0````-0``<)R=`0`5````````
M``,```!`H`$`$0```,03```2````*````!,````(`````0``<`$````%``!P
M`@````8``'``````"@``<!P````1``!P:@```!(``'`>````$P``<"0````>
M````"````/O__V\!```(_O__;P03``#___]O`P```/#__V\P$@``````````
M````````````````````````````````````````````````````````80``
M`&H```````````````T````J``````````````!````````````````H````
M2P````````!&````3````"(`````````4P```!H````#````+`````D````1
M````/````"\``````````````%0````5````+@``````````````(P```!T`
M```]```````````````6````6@`````````U`````````#,`````````9@``
M`!0````2````)@````````!G````&P```%L```!%````40``````````````
M&0```$<````Y````1`````````````````````````!/`````````"$`````
M`````````&$````G`````````"T````7````*0```````````````@````H`
M```_````9````!P````0````-``````````D````(```````````````$P``
M`!@`````````/@```!\```!!````)0```#`````Z````````````````````
M`````````````````````&,``````````````&4`````````````````````
M````3@```&(`````````#```````````````0@````0```!#````````````
M`````````````%P```!7``````````````````````````X````V````.P``
M```````Q````2````!X````K`````````#(```!=````:0```&````!-````
M.````````````````````#<```````````````````!?````2@``````````
M``````````\`````````"```````````````7@````L```!)````````````
M``!8`````````%4`````````````````````````4````%(`````````````
M`%8``````````````%D`````````:```````````````!0``````````````
M``````<```````````````````````````````8`````````````````````
M````````````````````````````````````[!,````````#``T`@0,``&18
M```(````$@`.`#8$``#D(@``&````!(`#@`!`````0`````````3`/'_>`0`
M``"@`0``````(``5`!$#`````````````!$```!'!```L"X``$@````2``X`
M*@0````_``!@`0``$@`.`&($``#,H0$``````!``&`!I!```U"4``"P````2
M``X`%`0````F``!\`0``$@`.``<$``!X,```"`L``!(`#@#E`P``]%,``/P!
M```2``X`=@0```"@`0``````$``5`/,"``!P7```!````!$`$0"#!````*`!
M```````0`!4`IP,``-@A```,`0``$@`.`!(````PH`$``````!$`%@!Q`P``
MP%<``*0````2``X`(`0``""@`0`$````$0`5`(H$``#PL0$``````!``&0#Z
M`P``?"<``(0&```2``X`\`,``/!5``#0`0``$@`.`(\$``#,H0$``````!``
M&0";!```A"$``%0````2``X`>0(``#`4``#\`@``$@`.`*,$```P%P``````
M`!(`#@#/`P``_"(``-@"```2``X`O0,``/@N``"``0``$@`.`!(#````````
M`````"$```"K!````"X``+`````2``X`N00``#`4````````$``.`,`$``#,
MH0$``````!``&0#<`P``1%,``+`````2``X`D0,``(`[``"``P``$@`.`+$"
M```@7````````!(```#O`0``$%P````````2````1@(```!<````````$@``
M`+`!``#P6P```````!(```"V`0``X%L````````2````$P,`````````````
M$0```#X"``#06P```````!(```"S```````````````@````!0(``,!;````
M````$@```*<"``"P6P```````!(```"J````H%L````````2````S0```)!;
M````````$@```)D``````````````!(```#&`@``@%L````````2````W```
M`'!;````````$@```!,"``!@6P```````!(```#S````4%L````````2````
MC@```$!;````````$@```/<!```P6P```````!(````$`0``(%L````````2
M````@````!!;````````$@```+\"````6P```````!(```#>`0``\%H`````
M```2````;0``````````````$@```*$"``#@6@```````!(````H`@``T%H`
M```````2````$`$``,!:````````$@```!L!``"P6@```````!(````P`0``
MH%H````````2````R@$``)!:````````$@```&P"``"`6@```````!(```#4
M`@``<%H````````2````7@```&!:````````$@```&4"``!06@```````!(`
M``"6`@``0%H````````2````/`$`````````````(@```$L!```P6@``````
M`!(```!G`0``(%H````````2`````@,``!!:````````$@```%L!````6@``
M`````!(````:`@``\%D````````2````U@$``.!9````````$@```!L#``#0
M60```````!(```!3````P%D````````2````;@$``+!9````````$@```'X"
M``"@60```````!(```!\`0`````````````1````10```)!9````````$@``
M`"\"``"`60```````!(```")`0`````````````1````7@(``'!9````````
M$@```.P"``!@60```````!(```#;`@``4%D````````2````.P```$!9````
M````$@```"P````P60```````!(```!=`@``(%D````````2````FP(``!!9
M````````$@```!P``````````````!(````M`P`````````````1````S0(`
M``!9````````$@```$\"``#P6````````!(```!`````X%@````````2````
M-@(``-!8````````$@````H#`````````````!$```!9!```P%@````````2
M````E`$`````````````(````-$!``"P6````````!(```"'`@``````````
M```B````(0(``*!8````````$@```%8"``"06````````!(`````7T193D%-
M24-?3$E.2TE.1P!?7U),1%]-05``8F]O=%]$>6YA3&]A9&5R`'!E<FQ?8V]N
M<W1R=6-T`'!E<FQ?9G)E90!P97)L7V1E<W1R=6-T`'!E<FQ?86QL;V,`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`
M<&5R;%]P87)S90!097)L7V%T9F]R:U]L;V-K`'!E<FQ?<G5N`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S=E]S971P=FX`4&5R;%]C<F]A:U]M
M96UO<GE?=W)A<`!097)L7VYE=UA37V9L86=S`%!E<FQ?;6=?<V5T`%!E<FQ?
M;F5W6%,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]G971?<W8`7U]G;6]N
M7W-T87)T7U\`4&5R;%]G=E]F971C:'!V`%!E<FQ?<V%F97-Y<VUA;&QO8P!0
M97)L7W-V7W-E='!V`%!,7V1O7W5N9'5M<`!03%]T:')?:V5Y`%])5$U?9&5R
M96=I<W1E<E1-0VQO;F5486)L90!C;&]S90!P=&AR96%D7V=E='-P96-I9FEC
M`&]P96XV-`!R96%D`&QS965K-C0`7U]E<G)N;U]L;V-A=&EO;@!O<&5N9&ER
M`%]?<W1R;F-P>5]C:&L`7U]F<')I;G1F7V-H:P!A8V-E<W,`9V5T<&ED`'-T
M<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!C;&]S961I<@!S
M=')D=7``<W1R<W1R`&QS=&%T-C0`<W1R8VAR`%]?;&EB8U]S=&%R=%]M86EN
M`')E861L:6YK`%]?8WAA7V9I;F%L:7IE`&5X:70`<FUD:7(`;6MD:7(`<F5A
M9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M8VAR`'-T<G1O:P!M96UC<'D`<W1R
M;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%])3U]S=&1I;E]U<V5D`')E
M86QL;V,`<W1D97)R`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T
M86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S0`;&EB<'1H<F5A9"YS;RXP
M`&QI8F,N<V\N-@!L9"YS;RXQ`%]?;&EB8U]C<W5?:6YI=`!?7VQI8F-?8W-U
M7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`<VAA7VEN:70`
M<VAA7W5P9&%T90!S:&%?9FEN86P`<&%R7VEN:71?96YV`'!A<E]M:W1M<&1I
M<@!P87)?9&ER;F%M90!M>5]P87)?<&P`<&%R7V-L96%N=7``<&%R7V-U<G)E
M;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!?961A=&$`<&%R
M7V)A<V5N86UE`%]?9&%T85]S=&%R=`!?9F1A=&$`7V5N9`!?7V)S<U]S=&%R
M=`!X<U]I;FET`%]?<W1A<G0`<&%R7V5N=E]C;&5A;@!?9G1E>'0`7V9B<W,`
M1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)
M0D-?,BXS+C(`1TQ)0D-?,BXS,P````````$``0`!``$``@`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``@`!``$``0`!
M``$`"@`"``(`!``$``(``@`!``H``P`!``$``0`"``$``@`!``$`"@`!``$`
M`@`$``$``@`"``$``0`!``D``@`"``$``@`"``$``0`"``(``0`"``D`"``!
M``$``@`!``$``@`!``8``@`'``$``0`&``(``0`%``(``@`"``(``@`"``$`
M!``#``(``@`!``$`:0,``!`````@````%&EI#0``!0#&!`````````$``@!/
M`P``$````#`````2:6D-```)`-`$```0````$&EI#0``!`#:!`````````$`
M!@!?`P``$`````````!T&6D)```*`.0$```0````<AEI"0``"`#P!```$```
M`!1I:0T```<`Q@0``!````"SD98&```&`/P$```0````$FEI#0```P#0!```
M$````!!I:0T```(`V@0``````````````````#2<`0`#````.)P!``,````@
MH`$``P```,BA`0`#`````@`</$0,G"<AX)D#X/^])Q``O*\<`+^O#(&"CP0`
M0!``````#(&9CPGX(`,`````'`"_CP@`X`,@`+TG```````````"`!P\``R<
M)R'@F0.P_[TG`(&9CS0`L*\8`+RO3`"_KT@`M:]$`+2O0`"SKSP`LJ\X`+&O
M:(&0CR0`I:\D`*4G(`"FKR``IB=0`*2O4`"D)P```HXL`**O"?@@`P`````8
M`+R/W("&CUB`F8^P@(2/\Q`1!"4HP``8`+R/.(&"CP``0I!G`$`0+(&9CT2!
MD8^0@)F/"?@@`P``)(X8`+R/9@-#D```)(Z0@)F/`@!C-`GX(`-F`T.@`$`#
M/%``L8]F`T60&`"\CP0`)"8!`*4T*QB#`&8#1:!]`&`0`P`Q)AR!F8\)^"`#
M@"`$`"0`I8\E.$``&`"\CU``J(\``**,7("#CRB`AH\``.*L)(""CP``9(P"
M``,IZ+''K*!?0B0(`.2L!`#BK"2`@H^D7T(D:@!@%`P`XJR`$`@`!`"C)!``
MY"0A$*(```!EC`0`8R0$`(0D_/]B%/S_A:P#``@E*("2CX!`"``D@(6/)3`@
M`B$0Z`#$@)F/$`"@K^RQ1([8(*4D"?@@`P``0*P8`+R/-@!`$"6(0``\@9F/
M*`"T)PGX(`/LL42.)2B``A@`O(\D@)./)("$CZ`8<R8ER&`"JP`1!#A=A"0N
M`$`0&`"\CU2!F8\)^"`#[+%$CA@`O(_0@)F/"?@@`P`````L`*./```"CCL`
M8A08`+R/3`"_CR40(`)(`+6/1`"TCT``LX\\`+*/.`"QCS0`L(\(`.`#4`"]
M)PGX(`,`````&`"\CR4@0``H@(*/+0"`$.RQ1*Q8@9F/1(&1CPGX(`,`````
M&`"\CY"`F8\)^"`#```DCA@`O(^*_P`0&P=`H*B`F8\)^"`#[+%$CA@`O(_&
M_P`0)8A``"B`E8_DL:2.!0"`$&"`F8\."A$$`````,S_`!`8`+R/)("$CR4H
M@`(ER&`";P`1!-1<A"08`+R/)2!``,/_0!#DL:*N\O\`$&"`F8^X@)F/"?@@
M`P````"@_P`0!``()%"!F8\)^"`#``````B!F8\)^"`#`0`$)``````E`.`#
M`0`1!``````"`!P\]`B<)R'@GP,E^```&("$CP``I8\$`*8G^/\!)"3HH0/@
M_[TG'("'CR"`B(\0`*BO%`"BKQ@`O:_X@)F/"?@@`P````#__P`0````````
M```"`!P\H`B<)R'@F0,H@(2/9(""CS2@A"0%`$00A(&9CP,`(!,`````"``@
M`P`````(`.`#``````(`'#QH")PG(>"9`RB`A(]D@(6/-*"$)",HI`"#$`4`
MPB\%`"$HH@!#*`4`!0"@$)R`F8\#`"`3``````@`(`,`````"`#@`P`````"
M`!P\'`B<)R'@F0/@_[TG&`"PKRB`D(\0`+RO'`"_K]"A`I(-`$`4C(&"CP4`
M0!!H@(*/C(&9CPGX(`,``$2,$`"\CR2`F8^0%SDGR_\1!``````!``(DT*$"
MHAP`OX\8`+"/"`#@`R``O2<"`!P\L`><)R'@F0,D@)F/R!<Y)\S_`!``````
M``````(`'#R0!YPG(>"9`\C_O2<0`+RO-`"_KS``MJ\L`+6O*`"TKR0`LZ\@
M`+*O'`"QKST`@!`8`+"OE(""CP``58PY`*`2/0`#)```@H`EH(``)9B@`$``
M0!`ED(``!`!#$``````!`$*"_/]`%`$`4B8CD%0"``"PCA```!(]`!8D)8B@
M`IB`F8\E(``")3!``@GX(`,E*(`"(1@2`@0`0!00`+R/``!B@`\`5A``````
M!``PCO/_`!8$`#$F-`"_CR40``(P`+:/+`"UCR@`M(\D`+./(`"RCQP`L8\8
M`+"/"`#@`S@`O2<CB#4"`0!2)H.($0`A@!("``!QKC0`OX\E$``",`"VCRP`
MM8\H`+2/)`"SCR``LH\<`+&/&`"PCP@`X`,X`+TG-`"_CR6````P`+:/+`"U
MCR40``(H`+2/)`"SCR``LH\<`+&/&`"PCP@`X`,X`+TGQO\`$"60```"`!P\
M,`:<)R'@F0,(_[TGW`"RKQ@`O*_T`+^O\`"WK^P`MJ_H`+6OY`"TK^``LZ_8
M`+&OU`"PKVB!DH\``$*.S`"BKP0`@!````````""@`\`0!0E@(``S`"CCP``
M0HYO`&(4]`"_C_``MX_L`+:/Z`"UC^0`M(_@`+./W`"RC]@`L8_4`+"/"`#@
M`_@`O2>$@)F/"?@@`P`````8`+R/[?]`$"6(0``D@)./*`"U)R2`E(]T7',F
M`!J4)J2`F8\)^"`#)2`@`CX`0!`8`+R/$P!#D-+_8R0$`&`4$P!6)`$`PY+V
M_V`0I("9CQ,`0I#2_T(D/`!`$/R`F8\)^"`#)2```B4@P`(8`+R/_("9CPGX
M(`,EN$``&`"\CR$@X@(4@9F/"?@@`P(`A"3__P8D&`"\CP$`!20E($``%`"V
MKR4X8`(0`+"O@("9CPGX(`,D`**O)2B@`A@`O(](@9F/"?@@`R0`I(___P,D
M&`"\CP8`0Q`D`*2/0`"BCP!``R0`\$(P(0!#$"7(@`)`@9F/"?@@`R0`I*\8
M`+R/)`"DCW2!F8\)^"`#`````!@`O(^D@)F/"?@@`R4@(`+$_T`4&`"\CXB`
MF8\)^"`#)2`@`A@`O(]@@9F/"?@@`R4@``*=_P`0&`"\CP$`PI+2_T(DPO]`
M%``````"`,*2K_]`$`````"]_P`0`````'S_$00`````&`"\C^'_`!`D`*2/
M4(&9CPGX(`,``````@`</`0$G"<AX)D#,/^])UR!F8\8`*4GQ`"PKQ``O*_(
M`+&O)8B``,P`OZ]H@9"/```"CKP`HJ\)^"`#``````\`0!00`+R/,`"CCP!`
M!"0`\&,P`P!D$`"@!#0)`&04`````+R`F8\"``4D"?@@`R4@(`(0`+R/`@``
M$`$`0BPE$```O`"DCP```XX%`(,4S`"_C\@`L8_$`+"/"`#@`]``O2=0@9F/
M"?@@`P`````"`!P\5`.<)R'@F0/([[TG-(&9C_\/!B0H$+*O$`"\KS`0M*\E
MH*``+!"SKQP`LR<@$+"O)8"``#00OZ\E*&`")!"QKVB!DH\D@(2/``!"CGQ<
MA"0<$**O"?@@`P`````=`$`8$`"\C___420@$",F(1A]`/SO8X`M`&`4````
M`!8`(!)$@8*/U("9CR\`!20E,"`""?@@`R4@8`(.`$`0$`"\CT2!@H^0@)F/
M"?@@`P``1(PE."`"$`"\CR4P8`(E*``"K("9CPGX(`,E($``#```$!``O(]$
M@8*/D("9CPGX(`,``$2,)3"``A``O(\E*``",(&9CPGX(`,E($``$`"\CQP0
MHX\``$*."@!B%#00OX\P$+2/+!"SCR@0LH\D$+&/(!"PCP@`X`,X$+TGU?\`
M$"6(0`!0@9F/"?@@`P`````"`!P\$`*<)R'@F0.X_[TG/0`")"@`L:\P`+.O
M)9B``"0`L*\E@*``$`"\KT0`OZ]``+>O/`"VKS@`M:\T`+2O+`"RKVB!D8\`
M`*.````ECAP`I:\"`&(4_("9CP$`$"8)^"`#)2```A@`I2<0`+R/)2!@`B2`
MF8^@&#DG@/X1!"6@0``0`+R/5`!`$"600`#\@)F/"?@@`R4@0``K$%0`0`!`
M$!``O(\8`+6/E("6CX"H%0```&6"/0`")`8`H!0E&&`"=```$"48```!`&6`
M`P"@$`$`8R3\_Z(4`````",8<P```-*.`@"$)A2!F8\A((,`"?@@`R&050(0
M`+R/&@!`$```0JX``,..`0!E)@``8H(]``<D(1AU````9(P'`$`4``""H`@`
M`!`E&(````"B@`$`I20F`$`0`0!BH"48@`#Z_T<4`0"$)#T`!"0!`&(D``!D
MH````X(!`$(D`0`0)OS_8!3__T.@'`"CCP``(HY-`&(41`"_CT``MX\\`+:/
M.`"UCS0`M(\P`+./+`"RCR@`L8\D`+"/"`#@`T@`O2<```*"`0!2)@$`$";N
M_T`0__]"H@```H(!`%(F`0`0)O?_0!3__T*BY_\`$`````#=_P`0)1B``)2`
MEH\``->.``#BCBT`0!`E$.`")9````0`0XPE($`"!`!")/S_8!0!`%(F`P"$
M)(`@!``H@(*/X+%#C!8`8!08@9F/%(&9CP$``R0)^"`#X+%#K!``O(_-_T`0
M)2!``'B!F8^`J!(`)2C@`@GX(`,E,*`"$`"\CR4@0````,*N`0!")A@`LJ^`
M$`(`(2""`)'_`!```("L)2B```GX(`,E(.`"$`"\CR4@0`"X_T`0``#"KO+_
M`!"`J!(`D_\`$```THX(``0DVO\`$"60``!0@9F/"?@@`P`````"`!P\6/^<
M)R'@F0/8_[TGD("9CR``L*\D`+^O&`"\KT2!D(\)^"`#```$CA@`O(^0@)F/
M"?@@`P``!(X8`+R/)2!``"R`AX\D@(6/9(&&C^B`F8\DG.<D"?@@`XQ<I208
M`+R/D("9CPGX(`,```2.&`"\CR4@0``4`*"O)("'CR2`A8_`@)F/G%_G)#"`
MAH^H7*4D"?@@`Q``IZ\D`+^/(`"PCP@`X`,H`+TG`@`</*S^G"<AX)D#X/^]
M)T2!@H^0@)F/'`"_KQ``O*\)^"`#``!$C!``O(\E($``'`"_CR``O2<L@(>/
M)("%CV2!AH_H@)F/))SG)`@`(`.,7*4D`@`</%C^G"<AX)D#N-^])R"!F8\\
M(+&O1""_KQ@`O*]`(+*O,!"R)S@@L*]H@9&/```BCC0@HJ\)^"`#`````"P`
MI"<8`+R/`1`&)!``HJ\!``4D)`"DKR2`@H\D@(>/@("9C\Q<0B3`7.<D"?@@
M`Q0`HJ\`$`8D&`"\CR4H0`(T@9F/"?@@`R0`I(\:`$`$&`"\CQ2!F8\!`$0D
M"?@@`R6`0``8`+R/"0!`$"4@0`!L@9F/)3```@GX(`,E*$`"(8!0`!@`O(\E
M($``````HC0@HX\``"*."0!B%$0@OX\E$(``0""RCSP@L8\X(+"/"`#@`T@@
MO2?U_P`0)2```%"!F8\)^"`#``````(`'#Q,_9PG(>"9`S2`F8^X_P`0````
M``(`'#PT_9PG(>"9`_CNO2<D@)F/^!"VKZ`8.2<@`+RO!!&_K^P0LZ\EF*``
MY!"QKR6(@`#@$+"O-`"E)P`1OJ_\$+>O]!"UK_`0M*_H$+*O:(&6CR2`A(\`
M`,*.U%R$)-P0HJ]/_1$$`````"\`!20@`+R/)2`@`@2!F8\)^"`#)8!``!@`
M0!`@`+R/)("$CR4H(`(D@)F/(!XY)Z'^$03@7(0D)1`@`B``O(_<$*2/``##
MCH4`@Q0$$;^/`!&^C_P0MX_X$+:/]!"UC_`0M(_L$+./Z!"RC^00L8_@$+"/
M"`#@`P@1O2?\@)F/)("2CPGX(`,E("`")2!@`B``O(]P@9F/"?@@`R680`#P
M7$4F(`"\C[2`F8\)^"`#)2!``"``O(_9_T`0);A``"2`@H\D@)2/)("5C]!<
M0B0L`**O``#B@D$`0!#\7)0F!@``$I"!F8\E*.`""?@@`R4@``(P`$`0(`"\
MC_R`F8\)^"`#)2#@`B\`!20E&$``(`"\CR$0X@+__T*`#`!%%"4@8`#^_V,D
M`0`")"$8XP(C$%<`+P`&)"$@0P`!`&"@__]C)`$`98#[_Z80``````$`8B8A
M$$0``!!"*+#_0!"`@)F/W`"^)_1<IR88`+&O`!`&)!0`M*\!``4D$`"WKPGX
M(`,E(,`#.`"E)R``O(](@9F/"?@@`R4@P`,&`$`4(`"\CU``HH\`@`,T`/!"
M,!H`0Q"\@)F/M("9C_!<128)^"`#)2```"``O(^4_T`0);A`````XH+!_T`4
M``````4``!(````````"DM+_0B0$`$`0`````"P`MX_4_P`0`0`$)`$``I+L
M_T`0M("9CRP`MX_._P`0`0`$)`$`!20)^"`#)2#``^/_0!0@`+R/)("$CR4H
MP`,D@)F/(!XY)QW^$03@7(0D(`"\CW"!F8\)^"`#)2#``WG_`!`@`+R/4(&9
MCPGX(`,```````"#@`<`8!`E$(```0"$)"\`8S@*$(,```"#@/S_8!0!`(0D
M"`#@`P`````"`!P\,/J<)R'@F0/8_[TG$`"\KR0`OZ\@`+&O.0"`$!P`L*\`
M`(*`-@!`$"6`@`#\@)F/"?@@`P`````O``,D__]&)"$P!@(K$`8"!0!`%!``
MO(\S```0`````#,`!A(```````#"@/S_0Q#__\8D`0#&)"L0!@(J`$`0+P`#
M)/__QB0I``82````````PH#\_T,4___&)`$`QB0$```0+P`#)```PH`%`$,4
M`````/__QB0K$`8"^O]`%``````C,-```@#")`$00BPB`$`0*("1CP`0!R3(
M@)F/`0#&)"4H``()^"`#X*$D)N"A(B8D`+^/(`"QCQP`L(\(`.`#*`"])R2`
MA(]P@9F/T%R$)"0`OX\@`+&/'`"PCP@`(`,H`+TGXO\&%B\``R0```."+P`"
M)`X`8A!P@9F/)("$CR0`OX\@`+&/'`"PC_Q<A"0(`"`#*`"])R0`OX\E$```
M(`"QCQP`L(\(`.`#*`"])R2`A(_F_P`0T%R$)`(`'#RT^)PG(>"9`Y#_O2<L
M@(*/(`"C)U0`LZ\`G$(D$`"\KVP`OZ\@`$@D:`"^KV0`MZ]@`+:O7`"UKU@`
MM*]0`+*O3`"QKT@`L*]H@9./``!DCD0`I*\``$>,$`!")!``8R3P_V>L]/]&
MC/C_18S\_T2,]/]FK/C_9:SV_T@4_/]DK"2`E(\<`+$G)("0CP``0I24@)*/
M`%V4)J`8$"8``&*D)2@@`B7(``(=_!$$)2"``A(`0!`0`+R/'`"CCP``0HZ`
M&`,`(1!#``0`0XST_V`0``!#K`@`0XP$`$(D_?]@%```0ZPE*"`")<@``@S\
M$00E((`"\/]`%!``O(\D@)2/E("2CPQ=E"8E*"`")<@``@/\$00E((`"$@!`
M$!``O(\<`*./``!"CH`8`P`A$$,`!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4
M``!#K"4H(`(ER``"\OL1!"4@@`+P_T`4$`"\CR2`E(^4@)*/%%V4)B4H(`(E
MR``"Z?L1!"4@@`(2`$`0$`"\CQP`HX\``$*.@!@#`"$00P`$`$.,]/]@$```
M0ZP(`$.,!`!")/W_8!0``$.L)2@@`B7(``+8^Q$$)2"``O#_0!00`+R/)("4
MCY2`DH\@790F)2@@`B7(``+/^Q$$)2"``A(`0!`0`+R/'`"CCP``0HZ`&`,`
M(1!#``0`0XST_V`0``!#K`@`0XP$`$(D_?]@%```0ZPE*"`")<@``K[[$00E
M((`"\/]`%!``O(\D@)2/E("2CRA=E28E*"`")<@``K7[$00E(*`"$@!`$!``
MO(\<`*./``!"CH`8`P`A$$,`!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#
MK"4H(`(ER``"I/L1!"4@H`+P_T`4$`"\CR2`E8^4@)*/.%VU)B4H(`(ER``"
MF_L1!"4@H`(2`$`0$`"\CQP`HX\``$*.@!@#`"$00P`$`$.,]/]@$```0ZP(
M`$.,!`!")/W_8!0``$.L)2@@`B7(``**^Q$$)2"@`O#_0!00`+R/)("5CY2`
MDH_47+8F)2@@`B7(``*!^Q$$)2#``A(`0!`0`+R/'`"CCP``0HZ`&`,`(1!#
M``0`0XST_V`0``!#K`@`0XP$`$(D_?]@%```0ZPE*"`")<@``G#[$00E(,`"
M\/]`%!``O(\D@)>/E("2CT1=]B8E*"`")<@``F?[$00E(,`"$@!`$!``O(\<
M`*./``!"CH`8`P`A$$,`!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H
M(`(ER``"5OL1!"4@P`+P_T`4$`"\CR2`EH^4@)*/4%W>)B4H(`(ER``"3?L1
M!"4@P`,2`$`0$`"\CQP`HX\``$*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,
M!`!")/W_8!0``$.L)2@@`B7(``(\^Q$$)2#``_#_0!00`+R/)(">CY2`DH]<
M7=XG)2@@`B7(``(S^Q$$)2#``Q(`0!`0`+R/'`"CCP``0HZ`&`,`(1!#``0`
M0XST_V`0``!#K`@`0XP$`$(D_?]@%```0ZPE*"`")<@``B+[$00E(,`#\/]`
M%!``O(\D@)Z/E("2C^!<WB<E*"`")<@``AG[$00E(,`#$@!`$!``O(\<`*./
M``!"CH`8`P`A$$,`!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(E
MR``""/L1!"4@P`/P_T`4$`"\CR2`A(\E*"`")<@``@'[$01H780D$`"\CS4`
M0!`E*$``)("2CR`>4B8ER$`"6?P1!%!=Q"80`+R/)("$CR4H(`(ER``"\_H1
M!'Q=A"00`+R/!@!`$"4H0``D@(2/)<A``DS\$020780D$`"\CR2`A(\E*"`"
M)<@``N;Z$02<780D$`"\CQT`0!`E*$``)<A``D#\$0347*0F$`"\CR2`A8\H
M780F)<A``CK\$03,7:4D1`"CCP``8HXK`&(4$`"\CVP`OX]H`+Z/9`"WCV``
MMH]<`+6/6`"TCU0`LX]0`+*/3`"QCT@`L(\(`.`#<`"])R2`DH_0_P`0(!Y2
M)B2`A(\E*"`")<@``L+Z$02L780D!P!`$!``O(]$7>0F)<A``AS\$00E*$``
MW/\`$!``O(\D@(6/"@`&))B`F8\Q`*0G"?@@`\!=I234_T`4$`"\CSL`I2<E
MR$`"#OP1!$1=Y";._P`0$`"\CU"!F8\)^"`#``````(`'#PP\IPG(>"9`]#_
MO2?__P,D*`"QKR0`L*\0`+RO+`"_KVB!D(\H@)&/```$CA"@(HX<`*2O"0!#
M$"2`A(\<`*2/```#CA8`@Q0L`+^/*`"QCR0`L(\(`.`#,`"])Q@`I2<D@)F/
MH!@Y)XSZ$01$780D"`!`$!``O(\``$*`!0!`$``````P`$(X*Q`"`.O_`!`0
MH"*N)1```.C_`!`0H"*N4(&9CPGX(`,``````@`</(#QG"<AX)D#X/^])TR!
MF8\0`+RO'`"_KPGX(`,`````$`"\CX"!F8\)^"`#)2!```(`0!`<`+^/``!"
MC`@`X`,@`+TG`@`</#CQG"<AX)D#N/^])R2`F8\H`*4G.`"RKZ`8.2<@`+RO
M/`"SKS0`L:\EB(``1`"_KT``M*\P`+"O:(&2CR2`DX\``$*.T%UD)BP`HJ]5
M^A$$``````4`0!`@`+R/)8!`````0H`0`$`4E(&9CRP`HX\``$*./@!B%-!=
M9"8E*"`")("9CT0`OX]``+2//`"SCR`>.2<X`+*/-`"QCS``L(^@^P`02`"]
M)R4H(`()^"`#)2```@P`0!`@`+R/+`"CCP``0HXJ`&(41`"_CT``M(\\`+./
M.`"RCS0`L8\P`+"/"`#@`T@`O2?\@)F/"?@@`R4@(`(E(``"(`"\C_R`F8\)
M^"`#):!``"``O(\A((("%(&9CPGX(`,"`(0D__\&)"``O(\EH$```0`%)!@`
ML*\0`+&O)2"``B2`@H\D@(>/@("9C_!<0B3T7.<D"?@@`Q0`HJ\L`*./``!"
MC@0`8A0@`+R/T%UD)L7_`!`E*(`"4(&9CPGX(`,``````@`</+COG"<AX)D#
M$("])___`CQ0@0,TZ'^^K^1^123<?[6O):B``-A_M*\A&&(`T'^RK\Q_L:_L
M?[^OY'^WK^!_MJ_4?[.OR'^PKW#^O2<D@(2/"`"B)VB!GH\H`+RO"`"G)^!=
MD20D@)*/4($$-"2`E(\A$&(`)("#CR$@A0```,:/"`"E)S``HZ_P75(F(2B%
M`/!^0*S47&0D)("#CZ`8E";H?E*L%']`K-!<8R3T?E&L_'Y`K"7(@`+L?D.L
M3($#-"$89P```&:L)("#CY1=8R0$?T.L)("#C_A=8R0(?T.L)("#C]A<8R0,
M?T.L)("#CP!>8R00?T.L)("#CP1>8R3(^1$$^'Y#K`0`0!`H`+R/``!#@(T!
M8!0X@)F/3(&9CPGX(`,`````*`"\CX"!F8\)^"`#)2!``$T!0!`H`+R/``!0
MC$L!`!+__Q,\_("9CPGX(`,E(``"*`"\CT`@`@`4@9F/"?@@`P$`A"0```."
M)8A``!$`8!`H`+R/)("'CR6P(`(07O,D@("9CP$`$";_`&,P__\&)!``HZ\!
M``4D)2#``@GX(`,E.&`"`@#6)@```X+T_V`4*`"\C___%CPD@(2/4($"-"2`
MDX\`?]<F"`"C)R$05P#D?M8F(;A#`%"!`C20780D(1!6`"P<<R8$```0(;!#
M``0`Y(YL`(`0!`#W)B7(@`*&^1$$)2C``OG_0!`E@$````!"@/;_0!`ER&`"
M8OH1!"4@``+R_T`0*`"\CW"!F8\)^"`#)2```B@`O(]:`$`0);A``/R`F8\)
M^"`#)2#@`B4@(`(H`+R/_("9CPGX(`,EL$``*`"\CR&PP@($!-8F%(&9CPGX
M(`,E(,`"__\&)"@`O(\ED$```0`%)!P`L:\E($`"$`"WKR2`DX\D@(*/)("'
MCX"`F8_\7',F)%Y")!A>YR04`+.O"?@@`Q@`HJ_``04D*`"\C^"`F8\)^"`#
M)2!``O__`R0(`$,4*`"\C]B`F8\)^"`#`````!$``R0``$*,!@%#%"@`O(__
M_Q$\7(&9CU"!`C08?R4F"`"C)R$010`E($`""?@@`R$H0P`H`+R//0!`$"6`
M0`!\@8*/`0`%)"2`AH\EB```H("9CP``IXX``$2,:%[&)`GX(`,0`+*O*`"\
MCP@`HR=,@0(T(1!#````0XP``,*/X`%B%"40(`*0`;TG['^_C^A_OH_D?[>/
MX'^VC]Q_M8_8?[2/U'^SC]!_LH_,?[&/R'^PCP@`X`/P?[TG__\0/%"!`C3H
M?A`F"`"C)R$04``'```0(8!#``0`$HZ>_T`2);@`````0H(/`$`0!``0)B7(
M8`+Q^1$$)2!``O;_0!`H`+R/<(&9CPGX(`,E($`"*`"\CY#_0!0EN$``!``2
MCO#_0!8`````B_\`$"6X``!0@0(T"`"C)R$040`AN$,``$`#)#!_XHX`\$(P
MO?]#%'R!@H\X?^..3(&9CPGX(`,T`*.O-`"CC[7_8A0H`+R/,'_BCL`!`R3_
M`4(PL?]#%'R!@H\4@9F/"?@@`R4@P`+D?B4F*`"\CU"!`S0(`*0G(1AE`"7(
M@`(A*&0`)("$CR6(0`#>^!$$O%Z$)"@`O(]$`4`0)2A``#R`F8]O^Q$$``"D
MCB@`O(\^`4`0);A``/R`F8\)^"`#)2#@`B6P0``$`$(L$`!`%"@`O(\D@(6/
M_/_$)I"!F8\A(.0""?@@`\1>I20(`$`4*`"\CP0``B1``<(2(;#V`B\``B3[
M_\."/`%B$``````H@)6/__\#)!"@HHXE`4,0__\%/)X`0!#T@)F/)("6CR2`
M@H]$7<0F)("%C___%B01`!<D(!Y9),Q=I20.^A$$-`"YKR@`O(\@@9F/"?@@
M`P````#__P8D*`"\CP$`!20E("`"&`"BKQ0`LZ\0`+*O)("4CR2`AX^`@)F/
MG%^4)N1>YR0)^"`#'`"TKR@`O(\D@)6/%P``$/1>M2;8@)F/"?@@`P``````
M`$*,%P!7%"@`O(\@@9F/"?@@`P$`$";__P8D*`"\CP$`!20@`+2O)3B@`AP`
ML*\E("`"&`"BKQ0`LZ^`@)F/"?@@`Q``LJ\H`+R/X("9C\`!!20)^"`#)2`@
M`N7_5A`H`+R/=(&9CPGX(`,E($`")2@@`C``HH\T`+F/"?@@`]1<1"0H`+R/
M.("9CP;^$00E("`"/?\`$"@`O(___Q,\4($"-"4@(`+T?G$F"`"C)R$040#D
M?G,F(8A#`%"!`C0A$%,`!0``$"&80P`$`"2.%`"`$!2!F8\$`#$F)<B``EOX
M$00E*&`"^/]`$"@`O(\``$.`]?]@$'"!F8\)^"`#)2!``"@`O(^;_D`4)8!`
M``0`)([Q_X`4!``Q)OS_,284@9F/"?@@`PT`!"13``,D*`"\CR6(0``D@)"/
MFOX`$.A=$"9\@8./`0`%)"2`AH\EB```H("9CP``IXX``&2,+%[&)!0`HJ\)
M^"`#$`"RKP;_`!`H`+R/)2!``,K]$00P`**O"`"C)TR!`C0H`+R/(1!#````
M1(P``,./X0"#%#``HH^0`;TG<(&9CR4@0`#L?[^/Z'^^C^1_MX_@?[:/W'^U
MC]A_M(_4?[./T'^RC\Q_L8_(?["/"``@`_!_O2<0H*"N]("9CR4H```)^"`#
M)2#@`B@`O(]>_T`0):!``"2!F8\"`!8D__\0/.[_!B00`+:O__\')`GX(`,E
M($``_'\5)B@`O(]0@0(T"`"C)R$050`&``8DB(&9CR&H0P`E((`""?@@`R4H
MH`)0@0(T"`"C)R$04``A@$,`_'\"D@4`0!0H`+R/_7\"DD,``R2%`$,000`#
M)"2!F8\E,```)3@``!``H*\)^"`#)2"``O__$#PH`+R/0("9CY4&$03\?Q8F
M"`"C)R6H0``H`+R/4($"-"$05@`&```0(;!#`$2`F8\E*,`"M@81!"4@H`(H
M`+R/B(&9CP"`!C0E*,`""?@@`R4@@`(H`+R/]/]`'"4P0`"\?Q`FC("9CU"!
M`C0(`*,G(1!0`"4@@`()^"`#(:!#`"@`O(\E**`")2"``DB`F8\>!Q$$%``0
M)E"!`C0H`+R/"`"C)R$04``A@$,`)("'CR@`%B807O4D``""DB4@``*`@)F/
M__\&)`$`!20"`!`F$`"BKPGX(`,E.*`"`0"4)O7_T!8H`+R/__\"/"2`AX]0
M@00T@("9C]!_0R04`+.O(2""`!``LJ\(`*(G__\&)"$0@@!0@00TU%[G)/A_
M0*`A((,`)(""CP@`HR<!``4D(1B#`)Q?0B08`*.O)2`@`AP`HJ\)^"`#````
M`"@`O(\D@(*/(!Y")!W_`!`T`**OPOX`$```MXXD@):/4($"-.1^I20(`*,G
M(1!%`$1=Q"8ER(`"C?<1!"$H0P!O_T`0*`"\CP``0H!L_T`0,``#)&K_0Q`!
M``(DSOX`$!"@HJX$`+6.P_Z@$OR`F8\)^"`#)2"@`@0`0RR^_F`4*`"\CR2`
MA8_\_T(DD(&9CR$@H@()^"`#S%ZE)`JXH@*U_@`0*`"\C_Y_!))[_X,4)(&9
MC_]_`Y)Y_V(4)3```%@!HY-(``(D=O]B%"4X``!9`:.310`")'+_8A0`````
M__\'),;_!B00`+:O"?@@`R4@@`(I``8D*`"\CR4HH`*(@9F/"?@@`R4@@`+_
M_P8D*`"\CP$`!20E("`"&`"UKQ0`LZ\0`+*O)(""CR2`AX^`@)F/G%]")-1>
MYR2N_P`0'`"BKU"!F8\)^"`#``````(`'#RPY)PG(>"9`\#_O2>0@)F/,`"S
MKR0`L*\\`+^O$`"\KS0`M*\8`+0G*`"QKS@`M:\L`+*O:(&3CT2!D(\``&*.
M```$CAP`HJ\)^"`#`````!``O(\EB$``D("9CPGX(`,```2.)2B``A``O(]H
M`".2)("1CR2`A(]I`$.@H!@Q)B7((`(E]Q$$*%V$)`4`0!`0`+R/``!$@#$`
M`R2/`(,0`````$R`F8_3^A$$`````!``O(^0@)F/"?@@`P``!(X#``<D$`"\
MCP$`!B0E($``)("%CQ"!F8\)^"`#"%^E)!``O(\2`$`0)9!``)"`F8\)^"`#
M```$CA``O(\E($``$`!#CB2`AH\P@9F/``!EC`GX(`,,7\8D$`!"C@``0HP(
M`$*,@`5"?'X`0!00`+R/D("9CPGX(`,```2.`P`')!``O(\!``8D)2!``"2`
MA8\0@9F/"?@@`Q1?I200`+R/%0!`$"600``D@(2/)<@@`B4H@`+I]A$$X%R$
M)!``O(\EJ$`````$CED`0!"0@)F/"?@@`P`````E,*`"$`"\CR4@0``0`$..
M,(&9CPGX(`,``&6,$`"\CY"`F8\H@)6/"?@@`P``!(X0`+R/)9!``)"`F8\)
M^"`#```$C@$`!B00`+R/)2!``"2`A8_P@)F/"?@@`QA?I20E($`"$`"\CR4H
M0``D@(:/,(&9CPGX(`,P7\8D$`"\CY"`F8\)^"`#```$CB4H@`(0`+R/)<@@
M`FD`0*`D@(2/N/81!-1<A"00`+R/)8!``!@`0!#DL:*NX("9C\`!!20)^"`#
M)2```A$``R0%`$,0$`"\CP$`0R0"`&,L-@!@$"4X0``<`*./``!BCCH`8A0\
M`+^/.`"UCS0`M(\P`+./+`"RCR@`L8\D`+"/"`#@`T``O2<H@(*/4("9CX_\
M$03HL42,$`"\CR6`0`#B_T`4Y+&BKB2`A(_L@)F/"?@@`SA?A"0!`$*`=/]`
M$$R`F8]O_P`0``````GX(`,`````$`"\CQ``0XXH@(*/)("9CP``9(SHL4*,
MW!PY)Y#W$00``$6,IO\`$!``O(^0@)F/"?@@`P``!(X0`+R/)2!``!``0X[,
M@)F/"?@@`P``98QY_P`0$`"\CRB`@H\D@(2/)3```NR`F8_HL4*,7%^$)`GX
M(`,``$6,4(&9CPGX(`,``````@`</##AG"<AX)D#R/^])U2`F8\L`+*O$`"\
MKR@`L:\EB(``)`"PKS0`OZ\P`+.O:(&2CP``0HX<`**OL/D1!````````$.`
M)8!```<`8!`0`+R/`0!")"\`8S@*@$,```!#@/S_8!0!`$(D*("3C___`R00
MH&*.$@!#$"2`A(\&`$`0``````0`(!(````````B@AD`0!0D@(6/'`"CCP``
M0HXK`&(4-`"_CS``LX\L`+*/*`"QCR0`L(\(`.`#.`"])Q@`I2<D@)F/H!@Y
M)S/V$01$780D'`!`$!``O(\``$*`&0!`$#```R07`$,0`0`").3_`!`0H&*N
M!``&))B`F8\E(``""?@@`R1>I23B_T`4$`"\CQP`HX\``$*.#`!B%"2`F8\E
M("`"-`"_CS``LX\L`+*/`!HY)R@`L8\D`+"/;O8`$#@`O2?3_P`0$*!@KE"!
MF8\)^"`#``````(`'#S0WYPG(>"9`U#]O2=H@8J/.`"()!@`HB<0`+RO>`"-
M)*P"OZ__``P\J`*RKR4P0`"D`K&OH`*PKP``0XV<`J.O!``%C0@`""40`,8D
M]/_`K/S_P*P"&@4`^/\'C0)>!0``3@4``/]C,*`X!WP`*@4`)1AK``(\)P`E
M&&D`)"BL`/#_QZPE&&4`[?^H%?C_PZP``DLD:`!)C`@`0B1\`$"L.`!#C#P`
M18QD`$B,"`!'C"9((P$,`$:,)D`%`?C_0XS\_T6,)CCI`"8PR``F&&<`)BBF
M`$`H!0#"-P,`0!@#`"4HI@`E&&4`ZO]+%'@`0ZP``(>,@EH"/`0`AHP(`(N,
MF7E")`P`A8S"?@<`&`"NCT!I!@`@`(R,@L`+`(`O!0`0`(B,&`")C"5HKP$A
M<,(!!`"`K(!_"P`,`("L)2BX`!0`@*Q`&0<`'`"`K"5XY0$@`*6/(7#,`248
M;0`F:`D!@H`'`"$8;@"`-P8`)&BK`2$HH@"`QP<`)FBI`2$8;0`E,-``)F@/
M`27`!@,H`*:/)&BG`2$HJ0#"S@,`0'$#`"9HJ`$A**T`(3#"`"5HV0$F</@!
M(2BM`"1PPP&"B`,`(3#(`(!O`P`F&,\!,`"NC\*&!0!`R04`(1C#`"5HL0$E
M,#`#(7#"`2$89@`F,`T#(7#/`21XQ0""B`4`@#<%`"8H^`$X`*^/PH8#`$#)
M`P`A*,4!)3#1`"5P,`,A>.(!(2BN`"9PI@$A>/@!),##`8*(`P"`=P,`)A@-
M`R$8XP%``*^/PH8%`$#)!0`E<-$!)<`P`R%XX@$A&'@`)L#.`"%X[0$DP`4#
M@H@%`(!O!0`F*`8#(2CE`4@`KX_"A@,`0,D#`"5HL0$EP#`#(7CB`2$HN``F
MP,T!(7CF`23``P."B`,`@#<#`"88#@,A&.,!4`"OC\*&!0!`R04`)3#1`"7`
M,`,A>.(!(1AX`";`I@$A>.X!),`%`X*(!0"`=P4`)B@-`R$HY0%8`*^/PH8#
M`$#)`P`E<-$!)<`P`R%XX@$A*+@`)L#.`"%X[0$DP`,#@H@#`(!O`P`F&`8#
M(1CC`6``KX_"A@4`0,D%`"5HL0$EP#`#(7CB`2$8>``FP,T!(7CF`23`!0."
MB`4`@#<%`"8H#@,A*.4!:`"OC\*&`P!`R0,`)3#1`"7`,`,A>.(!(2BX`";`
MI@$A>.X!),`#`X*(`P"`=P,`)A@-`R$8XP%P`*^/PH8%`$#)!0`E<-$!)<`P
M`R%XX@$A&'@`)L#.`"%X[0$DP`4#@H@%`(!O!0`F*`8#(2CE`7@`KX_"A@,`
M0,D#`"5HL0$EP#`#(7CB`2$HN``FP,T!(7CF`23``P."B`,`@#<#`"88#@,A
M&.,!@`"OC\*&!0!`R04`)3#1`"7`,`,A>.(!(1AX`";`I@$A>.X!),`%`X*(
M!0"`=P4`)B@-`R$HY0&(`*^/PH8#`$#)`P`E<-$!)<`P`R%XX@$A*+@`)L#.
M`"%X[0$DP`,#@H@#`(!O`P`F&`8#(1CC`9``KX_"A@4`0,D%`"5HL0$EP#`#
M(7CB`2$8>``FP,T!(7CF`23`!0."B`4`@#<%`"8H#@,A*.4!F`"OC\*&`P!`
MR0,`)3#1`"7`,`,A>.(!(2BX`";`I@$A<.X!)'@#`X*(`P"`QP,`)ACM`:``
MKX_"A@4`0,D%`"$8PP$EP!$#)7`P`R%XX@$A&&X`)G#8`"%X[0$D:,4!@G`%
M`(`O!0`F:*8!(7CM`25HK@"H`*Z/PH8#`$#)`P`A<,(!)2@P`R%XY0$F*`T#
M(7#&`20HHP"",`,`@!\#`"8HN``A<,4!)2AF`+``IH_"A@\`0,D/`"$PP@`F
M&*4!(3#8`"08;P`E$#`#)AAM`"%PP@$A,,,`N`"CC]EN`CR"R`\`H>M"-(!_
M#P`A&&(`)7CY`2$8;0`F:*\`)FBN`2$8;0#``*V/PH8.`$#!#@""R`X`@'<.
M`"%HH@$EP!`#(3#8`"5PV0$A**4!)FCN`29HI@'"A@8`@L@&`$#!!@`A**T`
M@&\&`,@`IH\EP!`#(1AX`"$PP@`E:+D!(3#/`"9XS0$F>.,!PH8#`(+(`P!`
MP0,`(3#/`(!_`P#0`*./)<`0`R$HN``A&&(`)7CY`2$8;@`F<*\!)G#%`<*&
M!0""R`4`0,$%`"$8;@"`=P4`V`"ECR7`$`,A,-@`(2BB`"5PV0$A**T`)FCN
M`29HI@'"A@8`@L@&`$#!!@`A**T`@&\&`.``IH\EP!`#(1AX`"$PP@`E:+D!
M(3#/`"9XS0$F>.,!PH8#`(+(`P!`P0,`(3#/`(!_`P#H`*./)<`0`R$HN``A
M&&(`)7CY`2$8;@`F<*\!)G#%`<*&!0""R`4`0,$%`"$8;@"`=P4`\`"ECR7`
M$`,A,-@`(2BB`"5PV0$A**T`)FCN`29HI@'"A@8`@L@&`$#!!@`A**T`@&\&
M`/@`IH\EP!`#(1AX`"$PP@`E:+D!(3#/`"9XS0$F>.,!PH8#`(+(`P!`P0,`
M(3#/`(!_`P```:./)<`0`R$HN``A&&(`)7CY`2$8;@`F<*\!)G#%`<*&!0""
MR`4`0,$%`"$8;@"`=P4`"`&ECR7`$`,A,-@`(2BB`"5PV0$A**T`)FCN`29H
MI@'"A@8`@L@&`$#!!@`A**T`@&\&`!`!IH\EP!`#(1AX`"$PP@`E:+D!(3#/
M`"9XS0$F>.,!PH8#`(+(`P!`P0,`(3#/`(!_`P`8`:./)<`0`R$HN``A&&(`
M)7CY`2$8;@`F<*\!PH8%`"9PQ0%`P04`@L@%`"$8;@"`=P4`(`&ECR7`$`,A
M,-@`(2BB`"5PV0'"A@8`0,$&`"$HK0`F:.X!)<`0`R9HI@$A&'@`@L@&`"$H
MK0"`;P8`*`&FC\*&`P!`P0,`(3#"`"5HN0$EP!`#(2BX`"$PSP`FP,T!)L`#
M`X+(`P`A,-@`@,<#`#`!HX_"A@4`0'D%`"$88@`EP!D#)7CP`2$PSP`A&&X`
M)GBX`29XY0&"R`4`(1AO`(!_!0`X`:6/PH8&`$!Q!@`A**(`)7CY`25PT`$A
M**T`)F@/`R$8;@`F:*8!(2BM`$`!K8_"A@,`0'$#`(+(!@"`-P8`)7#0`2%H
MH@$A**X`)7#9`"8P[@$A:+@!)C##`"%HI@&"@`,`@#<#`$@!HX_"S@4`0,$%
M`"$88@`EP!D#(<BX`27`T``F:-@!(1AO`"9HI0$A&&T`4`&MCX)X!0"`+P4`
MPH89`$`Q&0`A:*(!)2BO`"40T``A:*X!)G`%`R$88@`F<-D!(6BN`5@!KH\;
MCP(\PH8#`(*(&0!`,0,`@'\9`-R\0C0E>/$!)3#0`"%PP@$A:*8!)3"O`"20
MKP`A<-@!),##`(*(`P"`-P,`)1@2`V`!N(_"A@T`0,D-`"$8PP$E,-$`)7`P
M`R'``@,A&&X`)7#F`220Y@$AP`4#)'#-`25PT@$A<-@!:`&XC\*&`P!`R0,`
M@H@-`(`O#0`AP`(#)2BQ`"5H,`,A<,T!)6C%`"%X#P,D:*,!@L`#`(`?`P`D
MB,4`)1AX`'`!N(_"A@X`0,D.`"5HL0$A:*\!(<`"`R5X,`,A:*\!)7BC`"20
MHP`AP`8#)'CN`8*(#@"`-PX`)7#R`2%PV`%X`;B/PH8-`$#)#0`E,-$`)7@P
M`R'``@,A<,\!)7AF`"209@`AP`4#)'CM`8*(#0"`+PT`)6CR`2%HN`&``;B/
MPH8.`$#)#@`E*+$`)7@P`R'``@,A:*\!)7C%`"20Q0`AP`,#)'CN`8*(#@"`
M'PX`)7#R`2%PV`&(`;B/PH8-`$#)#0`E&'$`)7@P`R'``@,A<,\!)7BC`"20
MHP`AP`8#)'CM`8*(#0"`-PT`)6CR`2%HN`&0`;B/PH8.`$#)#@`E,-$`)7@P
M`R'``@,A:*\!)7AF`"209@`AP`4#)'CN`8*(#@"`+PX`)7#R`2%PV`&8`;B/
MPH8-`$#)#0`E*+$`)7@P`R'``@,A<,\!)7C%`"20Q0`AP`,#)'CM`8*(#0"`
M'PT`)6CR`2%HN`&@`;B/PH8.`$#)#@`E&'$`)7@P`R'``@,A:*\!)7BC`"20
MHP`AP`8#)'CN`8*(#@"`-PX`)7#R`2%PV`&H`;B/PH8-`$#)#0`E,-$`)7@P
M`R'``@,A<,\!)7AF`"209@`AP`4#)'CM`8*(#0"`+PT`)6CR`2%HN`&P`;B/
MPH8.`$#)#@`E*+$`)7@P`R'``@,A:*\!)7C%`"20Q0`AP`,#)'CN`8*(#@"`
M'PX`)7#R`2%PV`&X`;B/PH8-`$#)#0`E&'$`)7@P`R'``@,A<,\!)7BC`"20
MHP`AP`8#)'CM`8*(#0"`-PT`)6CR`2%HN`'``;B/PH8.`$#)#@`E,-$`)7@P
M`R'``@,A:*\!)7AF`"209@`AP`4#)'CN`8*(#@"`+PX`)7#R`2%PV`'(`;B/
MPH8-`$#)#0`E*+$`)7@P`R'``@,A<,\!)7C%`"20Q0`AP`,#)'CM`8*(#0"`
M'PT`)6CR`2%HN`'0`;B/PH8.`$#)#@`E&'$`)7@P`R'``@,A:*\!)7BC`"20
MHP`AP`8#)'CN`8*(#@"`-PX`)7#R`2%PV`'8`;B/PH8-`$#)#0`E,-$`)7@P
M`R'``@,A<,\!)7AF`"209@`AP`4#)'CM`8*(#0"`+PT`)6CR`2%HN`'@`;B/
MPH8.`$#)#@`E*+$`)7@P`R'``@,A:*\!)7C%`"'``P,DD,4`)'CN`25X\@$A
M>/@!Z`&XC\*&#0!`R0T`@H@.`(`?#@`AP`(#)1AQ`"5P,`,A>.X!)7"C`"$P
M!@,DB*,`)'#-`25PT0$A<,8!\`&FC\+.#P!`P0\`@H`-`(!O#0`A$,(`)6BP
M`24P&0,A<,8!)3!M`"$H10`D,,\`)!!M`"4PP@`A,,4`^`&ECV+*`CR"R`\`
MUL%"-(!_#P`A**(`)7CY`2$HHP`F&*\!)AAN`"$HHP```J./PH8.`$#!#@""
MR`X`@'<.`"7`$`,A&&(`(3#8`"5PV0$A&&T`)FCN`29HI@'"A@8`@L@&`$#!
M!@`A&&T`@&\&``@"IH\EP!`#(2BX`"$PP@`E:+D!(3#/`"9XS0$F>.4!PH8%
M`(+(!0!`P04`(3#/`(!_!0`0`J6/)<`0`R$8>``A**(`)7CY`2$HK@`F<*\!
M)G##`<*&`P""R`,`0,$#`"$HK@"`=P,`&`*CCR7`$`,A,-@`(1AB`"5PV0$A
M&&T`)FCN`29HI@'"A@8`@L@&`$#!!@`A&&T`@&\&`"`"IH\EP!`#(2BX`"$P
MP@`E:+D!(3#/`"9XS0$F>.4!PH8%`(+(!0!`P04`(3#/`(!_!0`H`J6/)<`0
M`R$8>``A**(`)7CY`2$HK@`F<*\!)G##`<*&`P""R`,`0,$#`"$HK@"`=P,`
M,`*CCR7`$`,A,-@`(1AB`"5PV0$A&&T`)FCN`29HI@'"A@8`@L@&`$#!!@`A
M&&T`@&\&`#@"IH\EP!`#(2BX`"$PP@`E:+D!(3#/`"9XS0$F>.4!PH8%`(+(
M!0!`P04`(3#/`(!_!0!``J6/)<`0`R$8>``A**(`)7CY`2$HK@`F<*\!)G##
M`<*&`P""R`,`0,$#`"$HK@"`=P,`2`*CCR7`$`,A,-@`(1AB`"5PV0$A&&T`
M)FCN`29HI@'"A@8`@L@&`$#!!@`A&&T`@&\&`%`"IH\EP!`#(2BX`"$PP@`E
M:+D!(3#/`"9XS0$F>.4!PH8%`(+(!0!`P04`(3#/`(!_!0!8`J6/)<`0`R$8
M>``A**(`)7CY`2$HK@`F<*\!PH8#`"9PPP%`P0,`@L@#`"$HK@"`=P,`8`*C
MCR7`$`,A,-@`(1AB`"5PV0'"A@8`0,$&`"$8;0`F:.X!)<`0`R9HI@$A*+@`
M@L@&`"$8;0"`;P8`:`*FC\*&!0!`P04`(3#"`"5HN0$EP!`#(1AX`"$PSP`F
MP,T!)L`%`X+(!0`A,-@`@,<%`'`"I8_"A@,`0'D#`"$HH@`EP!D#)7CP`2$P
MSP`A**X`)GBX`29XXP&"R`,`(2BO`(!_`P!X`J./PH8&`$!Q!@`A&&(`)7CY
M`25PT`$A&&T`)F@/`R$HK@`F:*8!(1AM`(`"K8_"A@4`0'$%`(+(!@"`-P8`
M)7#0`2%HH@$A&&X`)7#9`"8P[@$A:+@!)C#%`,*&`P`A:*8!B`*FCT#!`P""
MR`4`)<`0`X`O!0`AP+@!D`*MCR$PP@`E*+D`)LC%`2$PSP`A:*(!0'D8`"80
M(P/"AA@`@L@#`"$0P@"`'P,`(3"G`24X\`$A$$<`)1AY`"$PS@`F<*,`PLX"
M`$!I`@"">!@`@#\8`"9PV`$A,,X`)6BY`24X[P`A$$L`(1AI`"$PS0`(`(*L
M(3CH`!@`@ZPA**P```"&K!``AZP@`(6L)`"`K)P"HX\``$*-!@!B%*P"OX^H
M`K*/I`*QCZ`"L(\(`.`#L`*])U"!F8\)^"`#``````(`'#SLS)PG(>"9`^#_
MO2<4@9F/'`"_KQ``O*\)^"`#@``$)$5G!#PE*```>`!`K`$CA#0``$2LS>\$
M/`0`1:PE*```B:N$-`@`1*RZF`0\#`!%K"4H``#^W(0T$`!$K#(0!#P4`$6L
M)2@``'94A#08`$2LTL,$/!P`1:PE,```)3@``"4H```H`$:L\.&$-"P`1ZP@
M`$2L)`!%K#``1JPT`$>L'`"_CP@`X`,@`+TG`@`</#S,G"<AX)D#R/^])S``
MMJ\EL(``+`"UKR6HP``8`+"OP#`&`!``O*\E@*``-`"_KR@`M*\D`+.O(`"R
MKQP`L:\H`(*,+`"(C#``@XPT`(>,(3#"`$H``!7#)Q4`*Q#"`$@`0!0!`&(D
MP$`$`'@`Q8Y"%Q4`*`#&KD(G!``L`,"N)1`"`2$80P`A((<`*Q!B`#``PZXA
M$$0`.`#4)CT`H!0T`,*N0`"B*E$`0!0D@)./P/^U)H*)%0!@0',F`0`R)H"1
M$@`AD!("0``$)B4H``(E$(`"`P"HB`<`IX@+`*:(#P"CB```J)@$`*>8"`"F
MF`P`HY@0`*4D`P!(J```2+@'`$>H!`!'N`L`1J@(`$:X#P!#J`P`0[CN_Z04
M$`!")"4@P`(ER&`"S_H1!"6`H`#E_Q(6$`"\CX")$0`CJ+$";(&9CR4PH`(E
M*$`""?@@`R4@@`)X`-6N-`"_CS``MH\L`+6/*`"TCR0`LX\@`+*/'`"QCQ@`
ML(\(`.`#.`"])P$`8B0K&$,`(3AG`+;_`!`E&$``0``3)&R!F8\A((4"(Y!E
M`B4H``(J$+(""Y"B`@GX(`,E,$`">`#"CA``O(\A$$("Y/]3%'@`PJXD@)./
M)2#``B.HL@)@0',F)<A@`J'Z$00A@!("KO\`$!``O(_3_P`0)9```@(`'#Q`
MRIPG(>"9`\C_O2?D@)F/,`"UKS@`M20@`+&O)8B``!P`L*^`_P0D$`"\KR6`
MH``T`+^O+`"TKR@`LZ\D`+*O*`"RC#``LXS`*$)^H)@3?`$`0R0A$*("H)`2
M?#D`92@``$2@`I0R``*<,P!/`*`4(2"C`D``!B0E*```"?@@`R,PPP`0`+R/
M)("4CV!`E"8ER(`"=?H1!"4@``(X``8D$`"\CR4H``#D@)F/"?@@`R4@H`(E
M(``"<``3KB7(@`)J^A$$=``2KB4@``(#``*2$`"\CP``(J("``*6=(&9CP$`
M(J(```*.`A("``(`(J(```*.`P`BH@L``I($`"*B"@`"E@4`(J((``*.`A("
M``8`(J((``*.!P`BHA,``I((`"*B$@`"E@D`(J(0``*.`A("``H`(J(0``*.
M"P`BHAL``I(,`"*B&@`"E@T`(J(8``*.`A("``X`(J(8``*.#P`BHB,``I(0
M`"*B(@`"EA$`(J(@``*.`A("`!(`(J(@``*.$P`BHC0`OX\P`+6/+`"TCR@`
MLX\D`+*/(`"QCQP`L(\(`"`#.`"])S@`!B0E*```"?@@`R,PPP`0`+R/)("4
MC[O_`!!@0)0F`@`</'#(G"<AX)D#R/^])VR`F8\0`+RO,`"UKR6HP``L`+2O
M):"@`"@`LZ\EF(``)`"RKQP`L*\T`+^O^^X1!"``L:\0`+R/<("0CW2`DH\C
MD%`"@Y`2``D`0!(EB``````9C@$`,28E,*`")2B``@GX(`,E(&`"^?]1%@0`
M$"8T`+^/,`"UCRP`M(\H`+./)`"RCR``L8\<`+"/"`#@`S@`O2<(`.`#````
M```````"`!P\P,><)R'@F0-H@(*/*(&9CP@`(`,``$>,`````!"`F8\E>.`#
M"?@@`VD`&"00@)F/)7C@`PGX(`-H`!@D$("9CR5XX`,)^"`#9@`8)!"`F8\E
M>.`#"?@@`V0`&"00@)F/)7C@`PGX(`-B`!@D$("9CR5XX`,)^"`#80`8)!"`
MF8\E>.`#"?@@`V``&"00@)F/)7C@`PGX(`-?`!@D$("9CR5XX`,)^"`#7``8
M)!"`F8\E>.`#"?@@`UL`&"00@)F/)7C@`PGX(`-:`!@D$("9CR5XX`,)^"`#
M60`8)!"`F8\E>.`#"?@@`U@`&"00@)F/)7C@`PGX(`-7`!@D$("9CR5XX`,)
M^"`#5@`8)!"`F8\E>.`#"?@@`U0`&"00@)F/)7C@`PGX(`-3`!@D$("9CR5X
MX`,)^"`#40`8)!"`F8\E>.`#"?@@`U``&"00@)F/)7C@`PGX(`-/`!@D$("9
MCR5XX`,)^"`#3@`8)!"`F8\E>.`#"?@@`TT`&"00@)F/)7C@`PGX(`-,`!@D
M$("9CR5XX`,)^"`#2P`8)!"`F8\E>.`#"?@@`TH`&"00@)F/)7C@`PGX(`-)
M`!@D$("9CR5XX`,)^"`#2``8)!"`F8\E>.`#"?@@`T8`&"00@)F/)7C@`PGX
M(`-%`!@D$("9CR5XX`,)^"`#1``8)!"`F8\E>.`#"?@@`T,`&"00@)F/)7C@
M`PGX(`-"`!@D$("9CR5XX`,)^"`#00`8)!"`F8\E>.`#"?@@`T``&"00@)F/
M)7C@`PGX(`,_`!@D$("9CR5XX`,)^"`#/@`8)!"`F8\E>.`#"?@@`ST`&"00
M@)F/)7C@`PGX(`,\`!@D$("9CR5XX`,)^"`#.@`8)!"`F8\E>.`#"?@@`SD`
M&"00@)F/)7C@`PGX(`,X`!@D$("9CR5XX`,)^"`#-P`8)!"`F8\E>.`#"?@@
M`S8`&"00@)F/)7C@`PGX(`,U`!@D$("9CR5XX`,)^"`#-``8)!"`F8\E>.`#
M"?@@`S,`&"00@)F/)7C@`PGX(`,R`!@D$("9CR5XX`,)^"`#,0`8)!"`F8\E
M>.`#"?@@`R\`&"00@)F/)7C@`PGX(`,N`!@D$("9CR5XX`,)^"`#+0`8)!"`
MF8\E>.`#"?@@`RP`&"00@)F/)7C@`PGX(`,J`!@D$("9CR5XX`,)^"`#*``8
M)!"`F8\E>.`#"?@@`R<`&"00@)F/)7C@`PGX(`,F`!@D$("9CR5XX`,)^"`#
M)0`8)!"`F8\E>.`#"?@@`R0`&"0``````````````````````@`<//##G"<A
MX)D#X/^])Q``O*\<`+^O'`"_CP@`X`,@`+TG`````````````````0`"`"5S
M+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`
M+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O
M````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"
M54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"
M04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'
M3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$7TQ)0E)!4EE?4$%4
M2`!54T52`````%-94U1%30``+W1M<`````!414U01$E2`%1-4`!54T523D%-
M10`````E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%4
M2`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP
M+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P97)L`````#````!0
M05(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U-````%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A
M8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O
M9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H
M<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM>2`D;6%G
M:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C($Y/5$4Z
M("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P
M.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S
M("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A
M7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L
M("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU
M;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP
M(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B
M72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0[
M"F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?
M1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`]
M(")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X
M="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I
M;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H
M+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*
M?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H
M;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%
M("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F
M:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D
M9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C
M:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&
M:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI
M=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z
M("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM
M>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L
M("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A
M;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(
M02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\
M("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E
M;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*````7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("``````<&5R;'AS:2YC`````````(`8```4&```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#_____````````````````J%\`
M````````````````````````````````````````````````@#`4``#`5P``
M9%@```````````(````!`(`[``#8(0``^"X``/PB``!$4P``]%,``/!5``!\
M)P``>#`````F``!P6```(*`!```_```TH`$`R*$!`.P3```TG`$`.)P!````
M````````(%P``!!<````7```\%L``.!;````````T%L```````#`6P``L%L`
M`*!;``"06P```````(!;``!P6P``8%L``%!;``!`6P``,%L``"!;```06P``
M`%L``/!:````````X%H``-!:``#`6@``L%H``*!:``"06@``@%H``'!:``!@
M6@``4%H``$!:````````,%H``"!:```06@```%H``/!9``#@60``T%D``,!9
M``"P60``H%D```````"060``@%D```````!P60``8%D``%!9``!`60``,%D`
M`"!9```060``````````````60``\%@``.!8``#06````````,!8````````
ML%@```````"@6```D%@``,BA`0!'0T,Z("A$96)I86X@,3$N,BXP+3$V*2`Q
M,2XR+C```*`8`````'^`_/___P``````````.````!T````?`````!H`````
M_X#\____``````````#X````'0```!\````L'``````#@/S___\`````````
M`-`````=````'P```-P<`````!^`_/___P``````````.!```!T````?````
M(!X`````_X#\____``````````!(````'0```!\```#8(``````!@/S___\`
M`````````"@````=````'P```(0A``````"`_/___P``````````(````!T`
M```?````V"$`````!X#\____``````````!((```'0```!\```#D(@``````
M```````````````````````=````'P```/PB`````/_`_/___P``````````
M"!$``!T````?````U"4`````````````````````````````'0```!\`````
M)@`````#@/S___\``````````"@````=````'P```'PG`````/_`_/___P``
M````````<````!T````?`````"X``````X#\____```````````P````'0``
M`!\```"P+@``````@/S___\``````````"`````=````'P```/@N`````!^`
M_/___P``````````2````!T````?````>#``````_\#\____``````````"`
M@0``'0```!\```"`.P`````_@/S___\``````````$`````=````'P`````_
M``````^`_/___P``````````.````!T````?````,!0`````/X#\____````
M``````!0````'0```!\```!@0``````'@/S___\``````````+`"```=````
M'P```$13``````"`_/___P``````````(````!T````?````]%,`````?X#\
M____```````````X````'0```!\```#P50`````_@/S___\``````````#@`
M```=````'P```,!7`````#^`_/___P``````````.````!T````?````9%@`
M````````````````````````````'0```!\```!P6```````````````````
M```````````=````'P```$$/````9VYU``$'````!`4`+G-H<W1R=&%B`"YI
M;G1E<G``+DU)4%,N86)I9FQA9W,`+G)E9VEN9F\`+FYO=&4N9VYU+F)U:6QD
M+6ED`"YN;W1E+D%"22UT86<`+F1Y;F%M:6,`+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N:6YI
M=``N=&5X=``N34E04RYS='5B<P`N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T80`N<FQD7VUA<``N9V]T`"YS
M9&%T80`N8G-S`"YC;VUM96YT`"YP9'(`+F=N=2YA='1R:6)U=&5S`"YM9&5B
M=6<N86)I,S(`````````````````````````````````````````````````
M``````L````!`````@```)0!``"4`0``#0```````````````0`````````3
M````*@``<`(```"H`0``J`$``!@```````````````@````8````(@````8`
M`'`"````P`$``,`!```8```````````````$````&````"L````'`````@``
M`-@!``#8`0``)```````````````!``````````^````!P````(```#\`0``
M_`$``"````````````````0`````````3`````8````"````'`(``!P"```X
M`0``"0`````````$````"````%4````%`````@```%0#``!4`P``-`,```@`
M````````!`````0```!;````"P````(```"(!@``B`8``*`&```)`````@``
M``0````0````8P````,````"````*`T``"@-```'!0`````````````!````
M`````&L```#___]O`@```#`2```P$@``U`````@``````````@````(```!X
M````_O__;P(````$$P``!!,``,`````)`````P````0`````````AP````D`
M```"````Q!,``,03```H````"``````````$````"````)`````!````!@``
M`.P3``#L$P``/```````````````!`````````"6`````0````8````P%```
M,!0``&!$`````````````!``````````G`````$````&````D%@``)!8``"P
M`P`````````````$`````````*@````!````!@```$!<``!`7```)```````
M````````!`````````"N`````0````(```!P7```<%P``,`_````````````
M`!``````````M@````$````"````,)P``#"<```$```````````````$````
M`````,`````.`````P```#2<`0`TG```!```````````````!`````0```#,
M````#P````,````XG`$`.)P```0```````````````0````$````V`````$`
M```#`````*`!``"@```P```````````````0`````````-X````!`````P``
M`#"@`0`PH```!```````````````!`````````#G`````0````,``!!`H`$`
M0*```(@!`````````````!`````$````[`````$````#```0R*$!`,BA```$
M```````````````$`````````/,````(`````P```-"A`0#,H0``(!``````
M````````$`````````#X`````0```#``````````S*$``!\`````````````
M``$````!`````0$```$``````````````.RA``!@`P`````````````$````
M``````8!``#U__]O``````````!,I0``$````````````````0`````````6
M`0```0``````````````7*4```````````````````$``````````0````,`
B`````````````%RE```D`0`````````````!````````````
